; The CMD file for Morrigan
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional -- defaults to 15 if omitted)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas.
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /F, a    ;hold fwd while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;               command = ~30
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   You can combine them:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;   It's recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This matches the way most
;   popular fighting games implement their engine.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. Defaults to 15
;   if omitted
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands are given below. Delete, add, or modify as you wish.

;-| Special Motions |------------------------------------------------------

; Uppercut
[Command]
name = "uppercut_x"
command = ~F, D, DF, x

[Command]
name = "uppercut_y"
command = ~F, D, DF, y

[Command]
name = "uppercut_z"
command = ~F, D, DF, z


;-----------------
; QCF
[Command]
name = "QCF_x"
command = ~D, DF, F, x

[Command]
name = "QCF_y"
command = ~D, DF, F, y

[Command]
name = "QCF_z"
command = ~D, DF, F, z

;-----------------
; QCB
[Command]
name = "QCB_a"
command = ~D, DB, B, a

[Command]
name = "QCB_b"
command = ~D, DB, B, b

[Command]
name = "QCB_c"
command = ~D, DB, B, c

[Command]
name = "QCB_x"
command = ~D, DB, B, x

[Command]
name = "QCB_y"
command = ~D, DB, B, y

[Command]
name = "QCB_z"
command = ~D, DB, B, z

;-----------------

;downup
[Command]
name = "downup"
command = ~D, U

;downupfwd
[Command]
name = "downupfwd"
command = ~D, UF

;downupback
[Command]
name = "downupback"
command = ~D, UB


;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"       ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"       ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery" ;Required (do not remove)
command = x+y
time = 3

; -- SUPERS --

[Command]
name = "S_shadow1"
command = ~F, D, DF, x+y

[Command]
name = "S_shadow1"
command = ~F, D, DF, y+z

[Command]
name = "S_shadow1"
command = ~F, D, DF, z+x


[Command]
name = "dark1"
command = ~D, DF, F, a+b

[Command]
name = "dark1"
command = ~D, DF, F, b+c

[Command]
name = "dark1"
command = ~D, DF, F, a+c


[Command]
name = "S_solfist1"
command = ~D, DF, F, x+y

[Command]
name = "S_solfist1"
command = ~D, DF, F, x+z

[Command]
name = "S_solfist1"
command = ~D, DF, F, y+z


;-| Dir + Button |---------------------------------------------------------
[Command]
name = "fwd_a"
command = /F,a
time = 1

[Command]
name = "fwd_b"
command = /F,b
time = 1

[Command]
name = "fwd_c"
command = /F,c
time = 1

[Command]
name = "fwd_x"
command = /F,x
time = 1

[Command]
name = "fwd_y"
command = /F,y
time = 1

[Command]
name = "fwd_z"
command = /F,z
time = 1

[Command]
name = "back_a"
command = /B,a
time = 1

[Command]
name = "back_b"
command = /B,b
time = 1

[Command]
name = "back_c"
command = /B,c
time = 1

[Command]
name = "back_x"
command = /B,x
time = 1

[Command]
name = "back_y"
command = /B,y
time = 1

[Command]
name = "back_z"
command = /B,z
time = 1

[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

[Command]
name = "down_c"
command = /$D,c
time = 1

[Command]
name = "fwd_ab"
command = /F, a+b
time = 1

[Command]
name = "back_ab"
command = /B, a+b
time = 1

[Command]
name = "hold_x"
command = /x
time = 1

[Command]
name = "hold_y"
command = /y
time = 1

[Command]
name = "hold_z"
command = /z
time = 1

[Command]
name = "hold_a"
command = /a
time = 1

[Command]
name = "hold_b"
command = /b
time = 1

[Command]
name = "hold_c"
command = /c
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "taunt"
command = s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd"  ;Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback" ;Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup"   ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown" ;Required (do not remove)
command = /$D
time = 1


;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1]                  ;Don't change this
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.  
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in. 


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

;===========================================================================
;---------------------------------------------------------------------------
;Dark Illusion
[State -1]
type = ChangeState
value = 3039
triggerall = command = "dark1"
triggerall = power >= 1000
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = statetype != A
trigger2 = hitdefattr = SC, NA, SA
trigger2 = movecontact = 1
;---------------------------------------------------------------------------
;Super Shadow Blade
[State -1]
type = ChangeState
value = 3010
triggerall = command = "S_shadow1"
triggerall = power >= 1000
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = statetype != A
trigger2 = hitdefattr = SC, NA, SA
trigger2 = movecontact = 1

;---------------------------------------------------------------------------
;Not Activated -----Super Shadow Blade Level 2
;[State -1]
;type = Null;ChangeState
;value = 3010
;triggerall = command = "S_shadow2"
;triggerall = power >= 2000
;trigger1 = statetype != A
;trigger1 = ctrl = 1
;trigger2 = statetype != A
;trigger2 = hitdefattr = SC, NA, SA
;trigger2 = movecontact = 1

;----------------------------------------------------------------------------
;Super Air Solfist
[State -1]
type = ChangeState
value = 3020
triggerall = command = "S_solfist1"
triggerall = power >= 1000
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger1 = pos y < -20 

;-----------------------------------------------------------------------------
;Super Solfist
[State -1]
type = ChangeState
value = 3030
triggerall = command = "S_solfist1"
triggerall = power >= 1000
trigger1 = statetype != A
trigger1 = ctrl = 1

;----------------SPECIALS----------------
;----------------------------------------

;Solfist X
[State -1]
type = ChangeState
value = 1500
triggerall = command = "QCF_x"
trigger1 = statetype != A
trigger1 = ctrl = 1

;Solfist Y
[State -1]
type = ChangeState
value = 1510
triggerall = command = "QCF_y"
trigger1 = statetype != A
trigger1 = ctrl = 1

;Solfist Z
[State -1]
type = ChangeState
value = 1520
triggerall = command = "QCF_z"
trigger1 = statetype != A
trigger1 = ctrl = 1



;---------------------------------------------------------------------------
;Air Fireball

;AIR solfist X
[State -1]
type = ChangeState
value = 2000
triggerall = command = "QCF_x"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger1 = pos y < -20


;AIR solfist Y
[State -1]
type = ChangeState
value = 2010
triggerall = command = "QCF_y"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger1 = pos y < -20


;AIR solfist Z
[State -1]
type = ChangeState
value = 2020
triggerall = command = "QCF_z"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger1 = pos y < -20 



;---------------------------------------------------------------------------

;Shadow Blade
;X
[State -1]
type = ChangeState
value = 1000
triggerall = command = "uppercut_x"
trigger1 = statetype != A
trigger1 = ctrl = 1

;Shadow Blade
;Y
[State -1]
type = ChangeState
value = 1001
triggerall = command = "uppercut_y"
trigger1 = statetype != A
trigger1 = ctrl = 1

;Shadow Blade
;Z
[State -1]
type = ChangeState
value = 1002
triggerall = command = "uppercut_z"
trigger1 = statetype != A
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;Throw #1
[State -1]
type = ChangeState
value = 666
triggerall = P2Statetype = S
trigger1 = p2bodydist x <= 5
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger1 = command = "fwd_z"

;---------------------------------------------------------------------------
;Taunt
[state -1]
type = changeState
value = 195
triggerall = command = "taunt"
triggerall = ctrl = 1
trigger1 = statetype = S
trigger1 = Stateno != 195


;---------------------------------------------------------------------------
;RunFwd (FLY)
[State -1]
type = ChangeState
value = 101
trigger1 = command = "FF"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = command = "holdfwd"
trigger2 = stateno = 106
trigger3 = command = "holdfwd"
trigger3 = stateno = 102
;---------------------------------------------------------------------------
;RunBack (FLY)
[State -1]
type = ChangeState
value = 106
trigger1 = command = "BB"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = command = "holdback"
trigger2 = stateno = 101
trigger3 = command = "holdback"
trigger3 = stateno = 102
;-------------------------
;FlyUp-Forwards
[State -1]
type = ChangeState
value = 102
trigger1 = command = "holdup"
trigger1 = stateno = 101
trigger2 = command = "downup"
trigger2 = ctrl = 1
trigger2 = statetype = S
trigger3 = command = "downupfwd"
trigger3 = ctrl = 1
trigger3 = statetype = S
trigger4 = command = "holdup"
trigger4 = stateno = 106




;---------------------------------------------------------------------------


;Stand_X --CLOSE
[State -1]
type = ChangeState
value = 330
triggerall = command = "x"          ;Place name of command here
triggerall = command != "holddown"  ;Standing moves should have this line
triggerall = P2bodydist X <= 5  
trigger1 = statetype = S
trigger1 = ctrl = 1


;---------------------------------------------------------------------------
;Stand_Y --CLOSE
[State -1]
type = ChangeState
value = 340
triggerall = command = "y"
triggerall = command != "holddown"
triggerall = p2bodydist X <= 7 ;Near P2
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger3 = stateno = 300
trigger3 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger4 = stateno = 330
trigger4 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger5 = stateno = 210
trigger5 = movecontact = 1  ;If move hits, or is guarded by opponent

;---------------------------------------------------------------------------
;Stand_Z --CLOSE
[State -1]
type = ChangeState
value = 350
triggerall = command = "z"
triggerall = command != "holddown"
triggerall = p2bodydist X <= 9 ;Near P2
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger3 = stateno = 210
trigger3 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger4 = stateno = 330
trigger4 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger5 = stateno = 340
trigger5 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger6 = stateno = 300
trigger6 = movecontact = 1
trigger7 = stateno = 310
trigger7 = movecontact = 1

;---------------------------------------------------------------------------
;Stand_C --CLOSE
[State -1]
type = ChangeState
value = 250
triggerall = command = "c"
triggerall = command != "holddown"
triggerall = p2bodydist X <= 8 ;Near P2
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger3 = stateno = 210
trigger3 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger4 = stateno = 300
trigger4 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger5 = stateno = 310
trigger5 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger6 = stateno = 320
trigger6 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger7 = stateno = 330
trigger7 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger8 = stateno = 340
trigger8 = movecontact = 1  ;If move hits, or is guarded by opponent






;---------------------------------------------------------------------------

;Stand_X
[State -1]
type = ChangeState
value = 300
triggerall = command = "x"          ;Place name of command here
triggerall = command != "holddown"  ;Standing moves should have this line
 ;The following is true if Player is in stand state, and has control
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 300
trigger2 = movecontact = 1  ;If move hits, or is guarded by opponent

;---------------------------------------------------------------------------
;Stand_Y
[State -1]
type = ChangeState
value = 310
triggerall = command = "y"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger3 = stateno = 300
trigger3 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger4 = stateno = 330
trigger4 = movecontact = 1  ;If move hits, or is guarded by opponent
;trigger5 = stateno = 310
;trigger5 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger6 = stateno = 210
trigger6 = movecontact = 1  ;If move hits, or is guarded by opponent
;---------------------------------------------------------------------------
;Stand_Z
[State -1]
type = ChangeState
value = 320
triggerall = command = "z"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger3 = stateno = 210
trigger3 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger4 = stateno = 330
trigger4 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger5 = stateno = 340
trigger5 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger6 = stateno = 300
trigger6 = movecontact = 1
trigger7 = stateno = 310
trigger7 = movecontact = 1

;---------------------------------------------------------------------------


;---------------------------------------------------------------------------
;Stand_A
[State -1]
type = ChangeState
value = 200
triggerall = command = "a"          ;Place name of command here
triggerall = command != "holddown"  ;Standing moves should have this line
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 300
trigger2 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger3 = stateno = 330
trigger3 = movecontact = 1  ;If move hits, or is guarded by opponent

;---------------------------------------------------------------------------
;Stand_B
[State -1]
type = ChangeState
value = 210
triggerall = command = "b"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1
 ;Uncomment the following if you want to be able to "chain" the attack
trigger2 = stateno = 200
trigger2 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger3 = stateno = 300
trigger3 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger4 = stateno = 310
trigger4 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger5 = stateno = 330
trigger5 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger6 = stateno = 340
trigger6 = movecontact = 1  ;If move hits, or is guarded by opponent

;---------------------------------------------------------------------------
;Stand_C
[State -1]
type = ChangeState
value = 220
triggerall = command = "c"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger3 = stateno = 300
trigger3 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger4 = stateno = 210
trigger4 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger5 = stateno = 310
trigger5 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger6 = stateno = 320
trigger6 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger7 = stateno = 330
trigger7 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger8 = stateno = 340
trigger8 = movecontact = 1  ;If move hits, or is guarded by opponent
;---------------------------------------------------------------------------

;Crouch_X
[State -1]
type = ChangeState
value = 500
triggerall = command = "x"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Crouch_Y
[State -1]
type = ChangeState
value = 510
triggerall = command = "y"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = stateno = 500
trigger2 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger3 = stateno = 400
trigger3 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger4 = stateno = 501
trigger4 = movecontact = 1  ;If move hits, or is guarded by opponent

;---------------------------------------------------------------------------
;Crouch_Z
[State -1]
type = ChangeState
value = 520
triggerall = command = "z"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = stateno = 400
trigger2 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger3 = stateno = 500
trigger3 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger4 = stateno = 410
trigger4 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger5 = stateno = 510
trigger5 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger6 = stateno = 501
trigger6 = movecontact = 1  ;If move hits, or is guarded by opponent

;---------------------------------------------------------------------------
;Crouch_A
[State -1]
type = ChangeState
value = 400
triggerall = command = "a"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = stateno = 500
trigger2 = movecontact = 1
trigger3 = stateno = 501
trigger3 = movecontact = 1  ;If move hits, or is guarded by opponent

;---------------------------------------------------------------------------
;Crouch_B
[State -1]
type = ChangeState
value = 410
triggerall = command = "b"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = stateno = 400
trigger2 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger3 = stateno = 500
trigger3 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger4 = stateno = 510
trigger4 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger5 = stateno = 501
trigger5 = movecontact = 1  ;If move hits, or is guarded by opponent

;---------------------------------------------------------------------------
;Crouch_C
[State -1]
type = ChangeState
value = 420
triggerall = command = "c"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = stateno = 410
trigger2 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger3 = stateno = 510
trigger3 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger4 = stateno = 400
trigger4 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger5 = stateno = 500
trigger5 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger6 = stateno = 520
trigger6 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger7 = stateno = 501
trigger7 = movecontact = 1  ;If move hits, or is guarded by opponent

;---------------------------------------------------------------------------
;Jump_X
[State -1]
type = ChangeState
value = 700
triggerall = command = "x"
trigger1 = statetype = A
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Jump_Y
[State -1]
type = ChangeState
value = 710
triggerall = command = "y"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = stateno = 600
trigger2 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger3 = stateno = 700
trigger3 = movecontact = 1  ;If move hits, or is guarded by opponent
;---------------------------------------------------------------------------
;Jump_Z
[State -1]
type = ChangeState
value = 720
triggerall = command = "z"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = stateno = 600
trigger2 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger3 = stateno = 610
trigger3 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger4 = stateno = 700
trigger4 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger5 = stateno = 710
trigger5 = movecontact = 1  ;If move hits, or is guarded by opponent

;---------------------------------------------------------------------------
;Jump_A
[State -1]
type = ChangeState
value = 600
triggerall = command = "a"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = stateno = 700
trigger2 = movecontact = 1
;---------------------------------------------------------------------------
;Jump_B
[State -1]
type = ChangeState
value = 610
triggerall = command = "b"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = stateno = 710
trigger2 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger3 = stateno = 620
trigger3 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger4 = stateno = 610
trigger4 = movecontact = 1  ;If move hits, or is guarded by opponent

;---------------------------------------------------------------------------
;Jump_C
[State -1]
type = ChangeState
value = 620
triggerall = command = "c"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = stateno = 610
trigger2 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger3 = stateno = 710
trigger3 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger4 = stateno = 720
trigger4 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger5 = stateno = 730
trigger5 = movecontact = 1  ;If move hits, or is guarded by opponent
trigger6 = stateno = 620
trigger6 = movecontact = 1  ;If move hits, or is guarded by opponent



